==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=ro
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Adresa site-ului dumneavoastră', # MODIF
	'form_pet_aucune_signature' => 'Nici o semnătură nu corespunde acestui cod...', # MODIF
	'form_pet_confirmation' => 'Vă rugăm să confirmaţi semnătura dumneavoastră :',
	'form_pet_deja_signe' => 'Aţi semnat deja acest text.',
	'form_pet_envoi_mail_confirmation' => 'Un email de confirmare tocmai v-a fost trimis la adresa @email@. Pentru a valida semnătura dumneavoastră, va trebui să vizitaţi adresa de web menţionată in email.', # MODIF
	'form_pet_mail_confirmation' => 'Bună ziua,

Aţi cerut să semnaţi petiţia :
@titre@.

Aţi furnizat informaţiile următoare :
    Nume: @nom_email@
    Site: @nom_site@ - @url_site@


IMPORTANT...
Pentru a valida semnătura, trebuie să vizitaţi
adresa de mai jos (în caz contrat, cererea dumneavoastră va fi refuzată) :

    @url@


Mulţumim pentru participarea dumneavoastră
',
	'form_pet_nom_site2' => 'Numele site-ului dumneavoastră de Web', # MODIF
	'form_pet_probleme_liens' => 'Vă rugăm să reluati introducerea mesajului - suprimaţi legăturile hipertext.',
	'form_pet_probleme_technique' => 'Datorită unor probleme tehnice, semnăturile sunt deocamdată suspendate.',
	'form_pet_signature_validee' => 'Semnătura dumneavoastră este validată. Mulţumiri !',
	'form_pet_site_deja_enregistre' => 'Acest site este deja înregistrat',
	'form_pet_url_invalide' => 'Adresa URL indicată nu este valabilă.',
	'form_pet_votre_email' => 'Adresa dumneavoastră de email',
	'form_pet_votre_nom' => 'Numele sau pseudonimul dumneavoastră', # MODIF
	'form_pet_votre_site' => 'Dacă aveţi un site Web, puteţi să-l indicaţi mai jos',

	// I
	'info_adresse_email' => 'ADRESA EMAIL :',
	'info_signature_supprimee' => 'Semnătură suprimată',
	'info_signature_supprimee_erreur' => 'Eroare : acest cod de ştergere nu corespunde nici unei semnături', # MODIF
	'info_site_web' => 'SITE WEB :',

	// L
	'lien_reponse_article' => 'Răspuns la articol'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=ro
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Activaţi petiţia',
	'bouton_radio_pas_petition' => 'Fără petiţie',
	'bouton_radio_petition_activee' => 'Petiţie activată',
	'bouton_radio_supprimer_petition' => 'Ştergeţi petiţia',

	// F
	'form_pet_adresse_site' => 'Adresa site-ului dumneavoastră', # MODIF
	'form_pet_aucune_signature' => 'Nici o semnătură nu corespunde acestui cod...', # MODIF
	'form_pet_confirmation' => 'Vă rugăm să confirmaţi semnătura dumneavoastră :',
	'form_pet_deja_signe' => 'Aţi semnat deja acest text.',
	'form_pet_envoi_mail_confirmation' => 'Un email de confirmare tocmai v-a fost trimis la adresa @email@. Pentru a valida semnătura dumneavoastră, va trebui să vizitaţi adresa de web menţionată in email.', # MODIF
	'form_pet_mail_confirmation' => 'Bună ziua,

Aţi cerut să semnaţi petiţia :
@titre@.

Aţi furnizat informaţiile următoare :
    Nume: @nom_email@
    Site: @nom_site@ - @url_site@


IMPORTANT...
Pentru a valida semnătura, trebuie să vizitaţi
adresa de mai jos (în caz contrat, cererea dumneavoastră va fi refuzată) :

    @url@


Mulţumim pentru participarea dumneavoastră
',
	'form_pet_nom_site2' => 'Numele site-ului dumneavoastră de Web', # MODIF
	'form_pet_probleme_liens' => 'Vă rugăm să reluati introducerea mesajului - suprimaţi legăturile hipertext.',
	'form_pet_probleme_technique' => 'Datorită unor probleme tehnice, semnăturile sunt deocamdată suspendate.',
	'form_pet_signature_validee' => 'Semnătura dumneavoastră este validată. Mulţumiri !',
	'form_pet_site_deja_enregistre' => 'Acest site este deja înregistrat',
	'form_pet_url_invalide' => 'Adresa URL indicată nu este valabilă.',
	'form_pet_votre_email' => 'Adresa dumneavoastră de email',
	'form_pet_votre_nom' => 'Numele sau pseudonimul dumneavoastră', # MODIF
	'form_pet_votre_site' => 'Dacă aveţi un site Web, puteţi să-l indicaţi mai jos',

	// I
	'info_adresse_email' => 'ADRESA EMAIL :',
	'info_signature_supprimee' => 'Semnătură suprimată',
	'info_signature_supprimee_erreur' => 'Eroare : acest cod de ştergere nu corespunde nici unei semnături', # MODIF
	'info_site_web' => 'SITE WEB :',

	// L
	'lien_reponse_article' => 'Răspuns la articol'
);

?>
